============================
Content of samples directory
============================

deployments
~~~~~~~~~~~

Input configurations for "rally deployment" command


tasks
~~~~~

Input configurations for "rally task" command